@@ -23,6 +23,10 @@ from CsPy_Uploading.functions import save_excel_sheets_to_csv
 from CsPy_Uploading.functions import delete_folder_contents
 from CsPy_Uploading.functions import date_convert
 from CsPy_Uploading.functions import sql_to_workbook
+# TODO: Add int conversion for null values
+# TODO: Add better error exceptions
+# TODO: Add function/variable descriptions
+
 
 class UploadJob:
 
@@ -54,6 +58,7 @@ class UploadJob:
         self.update_job_config()
         self.data_from = self.get_upload_type()
         self.df = self.get_data_frame()
+        self.date_convert()
 
     def thg_log(self):
         """
@@ -144,20 +149,21 @@ class UploadJob:
         if self.upload_setting.date_conversion:
             convert_columns = []
             new_schema = []
+            new_df = self.df
             for i in self.schema:
                 if i.field_type in ('DATETIME', 'DATE'):
                     convert_columns.append(i.name)
 
             if len(convert_columns) != 0:
-                log('Date columns to be converted to keys: '.format(str(convert_columns)))
+                log('Date columns to be converted to keys: {}'.format(str(convert_columns)))
 
             for i in convert_columns:
                 try:
-                    self.log('Converting date column '.format(i))
-                    self.df[i] = pd.to_datetime(self.df[i])
-                    self.df[i] = self.df[i].fillna(dt.datetime(1990, 1, 1))
-                    self.df[i] = self.df[i].dt.strftime('%Y%m%d').astype(int)
-                    self.df[i] = self.df[i].replace(19900101, np.nan)
+                    self.log('Converting date column {}'.format(i))
+                    new_df[i] = pd.to_datetime(new_df[i])
+                    new_df[i] = new_df[i].fillna(dt.datetime(1990, 1, 1))
+                    new_df[i] = new_df[i].dt.strftime('%Y%m%d').astype(int)
+                    new_df[i] = new_df[i].replace(19900101, np.nan)
                 except Exception as e:
                     self.upload_details['Error'] = e
                     self.log('Failed to convert {} column to a date.'.format(i))
@@ -171,6 +177,11 @@ class UploadJob:
                     new_schema.append(i)
 
             self.schema = new_schema
+            self.df = new_df
+            self.job_config.schema = self.schema
+
+        else:
+            pass
 
     def get_credentials(self):
         """
@@ -298,8 +309,6 @@ class UploadJob:
                 df.columns(self.columns)
         end_time = dt.datetime.now()
         self.data_frame_info(start_time, end_time, df)
-        if self.upload_setting.date_conversion:
-            self.date_convert()
         return df
 
     def get_save_file_path(self, save_file_path):
@@ -331,7 +340,10 @@ class UploadJob:
             except Exception as e:
                 self.log("Failed to create temporary CSV folder.")
                 self.log('Error: {}'.format(e))
-                self.upload_details['Error'] = e
+                self.upload_details['Error'] = str(e)
+        else:
+            self.log('Using user defined save path')
+            self.upload_setting.use_save_file_path = True
         return save_file_path
 
     def get_upload_type(self):
@@ -459,9 +471,13 @@ class UploadJob:
                 self.run_upload_details()
                 self.log('DONE')
             if self.upload_setting.clear_csv_cache:
-                self.log('Removing Temporary CSV cache: {}'.format(self.save_file_path))
-                self.delete_folder_contents()
-                os.rmdir(self.save_file_path)
+                if self.upload_setting.use_save_file_path:
+                    self.log('Removing files from user defined CSV cache: {}'.format(self.save_file_path))
+                    self.delete_folder_contents()
+                else:
+                    self.log('Removing files temporary CSV cache: {}'.format(self.save_file_path))
+                    self.delete_folder_contents()
+                    os.rmdir(self.save_file_path)
             pass
 
     def get_upload_details(self):
@@ -574,7 +590,7 @@ class UploadSettings:
 
     def __init__(self, date_conversion, logging, clear_csv_cache):
         if date_conversion is None:
-            self.date_conversion = True
+            self.date_conversion = False
         else:
             self.date_conversion = date_conversion
         if logging is None:
@@ -583,6 +599,9 @@ class UploadSettings:
             self.logging = logging
         if clear_csv_cache is None:
             self.clear_csv_cache = True
+        else:
+            self.clear_csv_cache = clear_csv_cache
+        self.use_save_file_path = False
         self.vm_status = False
         self.use_account = False
         self.log_upload_settings()
